@@ -59,7 +59,7 @@ class StarkenHandler:
             "largo": "1",
             "tipoServicio": "0",
             "tipoDocumento1": api_settings.SENDER['DOCUMENT_TYPE'],
-            "numeroDocumento1": api_settings.SENDER['DOCUMENT_NUMBER'],
+            "numeroDocumento1": instance.reference,
             "generaEtiquetaDocumento1": api_settings.SENDER['GENERATE_LABEL_DOCUMENT_1'],
             "tipoDocumento2": "",
             "numeroDocumento2": "",
